==> hapi-fhir-structures-r4-3.4.0-sources.jar: org/hl7/fhir/r4/model/codesystems/AdverseEventSeriousness.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sun, May 6, 2018 17:51-0400 for FHIR v3.4.0


import org.hl7.fhir.exceptions.FHIRException;

public enum AdverseEventSeriousness {

        /**
         * Non-serious
         */
        NONSERIOUS, 
        /**
         * Serious
         */
        SERIOUS, 
        /**
         * Results in death
         */
        SERIOUSRESULTSINDEATH, 
        /**
         * Is Life-threatening
         */
        SERIOUSISLIFETHREATENING, 
        /**
         * Requires inpatient hospitalization or causes prolongation of existing hospitalization
         */
        SERIOUSRESULTSINHOSPITALIZATION, 
        /**
         * Results in persistent or significant disability/incapacity
         */
        SERIOUSRESULTSINDISABILITY, 
        /**
         * Is a congenital anomaly/birth defect
         */
        SERIOUSISBIRTHDEFECT, 
        /**
         * Requires intervention to prevent permanent impairment or damage (i.e., an important medical event that requires medical judgement)
         */
        SERIOUSREQUIRESPREVENTIMPAIRMENT, 
        /**
         * added to help the parsers
         */
        NULL;
        public static AdverseEventSeriousness fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("Non-serious".equals(codeString))
          return NONSERIOUS;
        if ("Serious".equals(codeString))
          return SERIOUS;
        if ("SeriousResultsInDeath".equals(codeString))
          return SERIOUSRESULTSINDEATH;
        if ("SeriousIsLifeThreatening".equals(codeString))
          return SERIOUSISLIFETHREATENING;
        if ("SeriousResultsInHospitalization".equals(codeString))
          return SERIOUSRESULTSINHOSPITALIZATION;
        if ("SeriousResultsInDisability".equals(codeString))
          return SERIOUSRESULTSINDISABILITY;
        if ("SeriousIsBirthDefect".equals(codeString))
          return SERIOUSISBIRTHDEFECT;
        if ("SeriousRequiresPreventImpairment".equals(codeString))
          return SERIOUSREQUIRESPREVENTIMPAIRMENT;
        throw new FHIRException("Unknown AdverseEventSeriousness code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case NONSERIOUS: return "Non-serious";
            case SERIOUS: return "Serious";
            case SERIOUSRESULTSINDEATH: return "SeriousResultsInDeath";
            case SERIOUSISLIFETHREATENING: return "SeriousIsLifeThreatening";
            case SERIOUSRESULTSINHOSPITALIZATION: return "SeriousResultsInHospitalization";
            case SERIOUSRESULTSINDISABILITY: return "SeriousResultsInDisability";
            case SERIOUSISBIRTHDEFECT: return "SeriousIsBirthDefect";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "SeriousRequiresPreventImpairment";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://hl7.org/fhir/adverse-event-seriousness";
        }
        public String getDefinition() {
          switch (this) {
            case NONSERIOUS: return "Non-serious";
            case SERIOUS: return "Serious";
            case SERIOUSRESULTSINDEATH: return "Results in death";
            case SERIOUSISLIFETHREATENING: return "Is Life-threatening";
            case SERIOUSRESULTSINHOSPITALIZATION: return "Requires inpatient hospitalization or causes prolongation of existing hospitalization";
            case SERIOUSRESULTSINDISABILITY: return "Results in persistent or significant disability/incapacity";
            case SERIOUSISBIRTHDEFECT: return "Is a congenital anomaly/birth defect";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "Requires intervention to prevent permanent impairment or damage (i.e., an important medical event that requires medical judgement)";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case NONSERIOUS: return "Non-serious";
            case SERIOUS: return "Serious";
            case SERIOUSRESULTSINDEATH: return "Results in death";
            case SERIOUSISLIFETHREATENING: return "Is Life-threatening";
            case SERIOUSRESULTSINHOSPITALIZATION: return "Requires or prolongs inpatient hospitalization";
            case SERIOUSRESULTSINDISABILITY: return "Results in persistent or significant disability/incapacity";
            case SERIOUSISBIRTHDEFECT: return "Is a congenital anomaly/birth defect";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "Requires intervention to prevent permanent impairment";
            default: return "?";
          }
    }


}

==> hapi-fhir-structures-r4-3.6.0-sources.jar: org/hl7/fhir/r4/model/codesystems/AdverseEventSeriousness.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Thu, Sep 13, 2018 09:04-0400 for FHIR v3.5.0


import org.hl7.fhir.exceptions.FHIRException;

public enum AdverseEventSeriousness {

        /**
         * Non-serious.
         */
        NONSERIOUS, 
        /**
         * Serious.
         */
        SERIOUS, 
        /**
         * Results in death.
         */
        SERIOUSRESULTSINDEATH, 
        /**
         * Is Life-threatening.
         */
        SERIOUSISLIFETHREATENING, 
        /**
         * Requires inpatient hospitalization or causes prolongation of existing hospitalization.
         */
        SERIOUSRESULTSINHOSPITALIZATION, 
        /**
         * Results in persistent or significant disability/incapacity.
         */
        SERIOUSRESULTSINDISABILITY, 
        /**
         * Is a congenital anomaly/birth defect.
         */
        SERIOUSISBIRTHDEFECT, 
        /**
         * Requires intervention to prevent permanent impairment or damage (i.e., an important medical event that requires medical judgement).
         */
        SERIOUSREQUIRESPREVENTIMPAIRMENT, 
        /**
         * added to help the parsers
         */
        NULL;
        public static AdverseEventSeriousness fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("Non-serious".equals(codeString))
          return NONSERIOUS;
        if ("Serious".equals(codeString))
          return SERIOUS;
        if ("SeriousResultsInDeath".equals(codeString))
          return SERIOUSRESULTSINDEATH;
        if ("SeriousIsLifeThreatening".equals(codeString))
          return SERIOUSISLIFETHREATENING;
        if ("SeriousResultsInHospitalization".equals(codeString))
          return SERIOUSRESULTSINHOSPITALIZATION;
        if ("SeriousResultsInDisability".equals(codeString))
          return SERIOUSRESULTSINDISABILITY;
        if ("SeriousIsBirthDefect".equals(codeString))
          return SERIOUSISBIRTHDEFECT;
        if ("SeriousRequiresPreventImpairment".equals(codeString))
          return SERIOUSREQUIRESPREVENTIMPAIRMENT;
        throw new FHIRException("Unknown AdverseEventSeriousness code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case NONSERIOUS: return "Non-serious";
            case SERIOUS: return "Serious";
            case SERIOUSRESULTSINDEATH: return "SeriousResultsInDeath";
            case SERIOUSISLIFETHREATENING: return "SeriousIsLifeThreatening";
            case SERIOUSRESULTSINHOSPITALIZATION: return "SeriousResultsInHospitalization";
            case SERIOUSRESULTSINDISABILITY: return "SeriousResultsInDisability";
            case SERIOUSISBIRTHDEFECT: return "SeriousIsBirthDefect";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "SeriousRequiresPreventImpairment";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://terminology.hl7.org/CodeSystem/adverse-event-seriousness";
        }
        public String getDefinition() {
          switch (this) {
            case NONSERIOUS: return "Non-serious.";
            case SERIOUS: return "Serious.";
            case SERIOUSRESULTSINDEATH: return "Results in death.";
            case SERIOUSISLIFETHREATENING: return "Is Life-threatening.";
            case SERIOUSRESULTSINHOSPITALIZATION: return "Requires inpatient hospitalization or causes prolongation of existing hospitalization.";
            case SERIOUSRESULTSINDISABILITY: return "Results in persistent or significant disability/incapacity.";
            case SERIOUSISBIRTHDEFECT: return "Is a congenital anomaly/birth defect.";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "Requires intervention to prevent permanent impairment or damage (i.e., an important medical event that requires medical judgement).";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case NONSERIOUS: return "Non-serious";
            case SERIOUS: return "Serious";
            case SERIOUSRESULTSINDEATH: return "Results in death";
            case SERIOUSISLIFETHREATENING: return "Is Life-threatening";
            case SERIOUSRESULTSINHOSPITALIZATION: return "Requires or prolongs inpatient hospitalization";
            case SERIOUSRESULTSINDISABILITY: return "Results in persistent or significant disability/incapacity";
            case SERIOUSISBIRTHDEFECT: return "Is a congenital anomaly/birth defect";
            case SERIOUSREQUIRESPREVENTIMPAIRMENT: return "Requires intervention to prevent permanent impairment";
            default: return "?";
          }
    }


}
